"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const time_span_1 = __importDefault(require("time-span"));
const Contracts_1 = require("../Contracts");
const exceptions = __importStar(require("../Exceptions"));
class TestsStore {
    constructor() {
        this._store = {
            passedCount: 0,
            skippedCount: 0,
            failedCount: 0,
            todoCount: 0,
            regressionCount: 0,
            total: 0,
            groups: [],
            duration: 0,
        };
    }
    get activeGroup() {
        return this._store.groups[this._store.groups.length - 1];
    }
    recordGroup(group) {
        this.open();
        this._store.groups.push({ title: group.title, failedTests: [], failedHooks: [] });
    }
    endGroup(group) {
        if (group.status === Contracts_1.IGroupStatus.FAILED && this.activeGroup.title === group.title) {
            const error = group.error;
            this.activeGroup.failedHooks.push({ title: error.fnName || error.lifecycle, error });
        }
    }
    recordTest(test) {
        this.open();
        if (test.status === Contracts_1.ITestStatus.FAILED) {
            this.activeGroup.failedTests.push({ title: test.title, error: test.error });
        }
        this._store.total++;
        switch (test.status) {
            case Contracts_1.ITestStatus.FAILED:
                this._store.failedCount++;
                break;
            case Contracts_1.ITestStatus.PASSED:
                this._store.passedCount++;
                break;
            case Contracts_1.ITestStatus.SKIPPED:
                this._store.skippedCount++;
                break;
            case Contracts_1.ITestStatus.TODO:
                this._store.todoCount++;
                break;
        }
        if (test.regression) {
            this._store.regressionCount++;
        }
    }
    open() {
        if (!this._processStart) {
            this._processStart = time_span_1.default();
        }
    }
    close() {
        if (!this._store.duration) {
            this._store.duration = this._processStart.rounded();
        }
    }
    getReport() {
        this.close();
        return this._store;
    }
}
exports.TestsStore = TestsStore;
function isCoreException(error) {
    return !!Object.keys(exceptions).find((e) => error instanceof exceptions[e]);
}
exports.isCoreException = isCoreException;
